@@ -316,7 +316,9 @@ macro_rules! return_if_arrow {
 
 macro_rules! trace_cur {
     ($p:expr, $name:ident) => {{
-        // println!("{}: {:?}", stringify!($name), $p.input.cur());
+        if cfg!(feature = "debug") {
+            log::debug!("{}: {:?}", stringify!($name), $p.input.cur());
+        }
     }};
 }
 
